# Version of java
%define javaver 1.8.0

# Alternatives priority
%define priority 18000

%define javadir     %{_jvmdir}/java-openjdk
%define jredir      %{_jvmdir}/jre-openjdk
%define javaplugin  libjavaplugin.so.%{_arch}

%define binsuffix      .itweb

Name:		icedtea-web
Version:	1.6.1
Release:	%mkrel 1
Summary:	Additional Java components for OpenJDK - Java browser plug-in and Web Start implementation

Group:      Networking/WWW
License:    LGPLv2+ and GPLv2 with exceptions
URL:        http://icedtea.classpath.org/wiki/IcedTea-Web
Source0:    http://icedtea.classpath.org/download/source/%{name}-%{version}.tar.gz

BuildRequires:  java-%{javaver}-openjdk-devel
BuildRequires:  desktop-file-utils
BuildRequires:  glib2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig(mozilla-plugin)
BuildRequires:  pkgconfig(x11)
BuildRequires:  junit
BuildRequires:  hamcrest
BuildRequires:  zip
# new in 1.5 to have  clean up for malformed XMLs
BuildRequires:  tagsoup

# For functionality and the OpenJDK dirs
Requires:      java-%{javaver}-openjdk

# For the mozilla plugin dir
Requires:       mozilla-filesystem

# When itw builds against it, it have to be also in runtime
Requires:      tagsoup

# Post requires alternatives to install plugin alternative.
Requires(post):   update-alternatives

# Postun requires alternatives to uninstall plugin alternative.
Requires(postun): update-alternatives

# Standard JPackage plugin provides.
Provides: java-plugin = 1:%{javaver}
Provides: javaws      = 1:%{javaver}

Provides:   java-%{javaver}-openjdk-plugin =  1:%{version}

%description
The IcedTea-Web project provides a Java web browser plugin, an implementation
of Java Web Start (originally based on the Netx project) and a settings tool to
manage deployment settings for the aforementioned plugin and Web Start
implementations. 

%package javadoc
Summary:    API documentation for IcedTea-Web
Group:      Documentation
Requires:   %{name} = %{version}-%{release}
Requires:   jpackage-utils
BuildArch:  noarch

%description javadoc
This package contains Javadocs for the IcedTea-Web project.

%prep
%setup -q

%build
autoreconf -vfi
CXXFLAGS="$RPM_OPT_FLAGS $RPM_LD_FLAGS" \
%configure2_5x \
    --with-pkgversion=%{_real_vendor}-%{release}-%{_arch} \
    --docdir=%{_datadir}/javadoc/%{name} \
    --with-jdk-home=%{javadir} \
    --with-jre-home=%{jredir} \
    --libdir=%{_libdir} \
    --program-suffix=%{binsuffix} \
    --prefix=%{_prefix}
%make

%install
%makeinstall_std

# icedteaweb-completion is currently not handled by make nor make install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/
cp icedteaweb-completion $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/

# Move javaws man page to a more specific name
mv $RPM_BUILD_ROOT/%{_mandir}/man1/javaws.1 $RPM_BUILD_ROOT/%{_mandir}/man1/javaws-itweb.1

# Install desktop files.
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/{applications,pixmaps}
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications javaws.desktop
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications itweb-settings.desktop
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications policyeditor.desktop

%find_lang %{name} --with-man --all-name

%check
make check

%post
alternatives \
  --install %{_libdir}/mozilla/plugins/libjavaplugin.so %{javaplugin} \
  %{_libdir}/IcedTeaPlugin.so %{priority} \
  --slave %{_bindir}/javaws javaws %{_prefix}/bin/javaws%{binsuffix} \
  --slave %{_mandir}/man1/javaws.1.xz javaws.1.xz \
  %{_mandir}/man1/javaws-itweb.1.xz

exit 0

%postun
if [ $1 -eq 0 ]
then
  alternatives --remove %{javaplugin} \
    %{_libdir}/IcedTeaPlugin.so
fi

exit 0

%files -f %{name}.lang
%{_sysconfdir}/bash_completion.d/*
%{_prefix}/bin/*
%{_libdir}/IcedTeaPlugin.so
%{_datadir}/applications/*
%{_datadir}/icedtea-web
%{_datadir}/man/man1/*
%{_datadir}/pixmaps/*
%doc NEWS README COPYING

%files javadoc
%{_datadir}/javadoc/%{name}
%doc COPYING




%changelog
* Tue Sep 15 2015 luigiwalser <luigiwalser> 1.6.1-1.mga5
+ Revision: 879679
- BR zip is still needed
- 1.6.1
- BR hamcrest and not zip
- install bash_completion file
- 1.5.3 (fixes CVE-2015-5234 and CVE-2015-5235)

* Tue Dec 02 2014 luigiwalser <luigiwalser> 1.5.2-1.mga5
+ Revision: 800291
- 1.5.2

* Wed Oct 15 2014 umeabot <umeabot> 1.5.1-3.mga5
+ Revision: 742049
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.1-2.mga5
+ Revision: 680444
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 luigiwalser <luigiwalser> 1.5.1-1.mga5
+ Revision: 663995
- 1.5.1
- remove upstreamed patches

* Tue Aug 05 2014 dmorgan <dmorgan> 1.5-1.mga5
+ Revision: 659866
- New version
  Build against openjdk8

* Fri Feb 07 2014 luigiwalser <luigiwalser> 1.4.2-1.mga5
+ Revision: 585370
- 1.4.2

* Fri Jan 10 2014 pterjan <pterjan> 1.4.1-3.mga4
+ Revision: 566100
- Add missing BuildRequires
- Fix Buildequires

* Sat Oct 19 2013 umeabot <umeabot> 1.4.1-2.mga4
+ Revision: 534962
- Mageia 4 Mass Rebuild

* Mon Sep 16 2013 oden <oden> 1.4.1-1.mga4
+ Revision: 480327
- 1.4.1 (fixes CVE-2013-4349)

* Sun Jun 23 2013 luigiwalser <luigiwalser> 1.4-1.mga4
+ Revision: 446041
- 1.4

* Sun Jun 23 2013 luigiwalser <luigiwalser> 1.3.2-2.mga4
+ Revision: 446036
- adapted to latest openjdk changes (from fedora)
- added build requires for autoconf and automake
- add patch from fedora with fix for new openjdk

* Wed Apr 17 2013 luigiwalser <luigiwalser> 1.3.2-1.mga3
+ Revision: 410342
- 1.3.2 (fixes CVE-2013-1926 and CVE-2013-1927)

* Sat Jan 12 2013 umeabot <umeabot> 1.3.1-2.mga3
+ Revision: 354169
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 08 2012 luigiwalser <luigiwalser> 1.3.1-1.mga3
+ Revision: 316479
- 1.3.1 (fixes CVE-2012-4540)

* Fri Sep 07 2012 dmorgan <dmorgan> 1.3-1.mga3
+ Revision: 289285
- New version 1.3

* Wed Aug 01 2012 luigiwalser <luigiwalser> 1.2.1-1.mga3
+ Revision: 277710
- 1.2.1 (fixes CVE-2012-3422 and CVE-2012-3423)

* Mon May 28 2012 dmorgan <dmorgan> 1.2-5.mga3
+ Revision: 248637
- Rebuild against java7

* Wed May 16 2012 dmorgan <dmorgan> 1.2-4.mga2
+ Revision: 235776
- Allow to build on arm as well
- Fix Requires(post) ( mga #5917)

* Wed May 16 2012 dmorgan <dmorgan> 1.2-3.mga2
+ Revision: 235770
- Requires mozilla-filesystem for update-alternatives to work

* Thu Apr 19 2012 dmorgan <dmorgan> 1.2-2.mga2
+ Revision: 231733
- Fix dandling links ( mga #4631)

* Tue Mar 20 2012 dmorgan <dmorgan> 1.2-1.mga2
+ Revision: 225136
- New version 1.2

* Sat Dec 17 2011 gil <gil> 1.1.4-1.mga2
+ Revision: 183243
- update to 1.1.4

* Tue Oct 18 2011 dmorgan <dmorgan> 1.1.3-1.mga2
+ Revision: 156434
- Do not own std dirs
- New version 1.1.3

  + gil <gil>
    - New version

* Tue Sep 20 2011 fwang <fwang> 1.0.4-1.mga2
+ Revision: 145970
- fix group
- fix bindir
- fix linkage

  + gil <gil>
    - update to 1.0.4

* Thu Jun 16 2011 dmorgan <dmorgan> 1.0.3-1.mga2
+ Revision: 108216
- New version 1.0.3

* Mon Apr 11 2011 tmb <tmb> 1.0.2-5.mga1
+ Revision: 83483
- fix ExclusiveArch so i586 gets built

* Mon Apr 11 2011 tmb <tmb> 1.0.2-4.mga1
+ Revision: 83472
- rebuild for missing package on i586

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-3.mga1
+ Revision: 82529
- Better obsoletes

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-2.mga1
+ Revision: 82525
- Fix openjdk version for the obsolete/provides
  Fix Groups
  Fix layout

* Sat Apr 09 2011 ahmad <ahmad> 1.0.2-1.mga1
+ Revision: 82490
- adapt the spec to Mageia
- add BR zip
- imported package icedtea-web

